<template>
  <div class="contacts-view">
    <SearchCommonView ref="searchCommonView" :query-class-options="queryClassOptions" :search-options="searchOptions" />
    <div class="btn-pager">
      <PublicFunctionBtnView :operates-list="operatesList" />
      <PagerView class="page" />
    </div>
    <TableCommonView ref="tableListRef" v-loading="loading" :table-list="tableList">
      <template slot="tableButton">
        <el-table-column label="操作" width="120" fixed="right">
          <template slot-scope="scope">
            <el-button @click="handleClick(scope.row)" type="text" size="small">编辑</el-button>
            <el-button type="text" size="small">跟进</el-button>
          </template>
        </el-table-column>
      </template>
    </TableCommonView>
    <!-- 新建/编辑联系人 -->
    <AddContactsDialog v-if="editConfig.visible" :edit-contacts-config="editConfig" />
  </div>
</template>

<script>
import AddContactsDialog from "@/views/client/contacts/AddContactsDialog"
import { getContactList } from "@/api/client/contacts"
export default {
  name: "ContactsView",
  props: {},
  components: {
    AddContactsDialog
  },
  computed: {},
  data() {
    return {
      tableList: {},
      loading: false,
      queryClassOptions: [
        { value: "1", label: "全部" },
        { value: "2", label: "本月生日" }
      ],
      searchOptions: [],
      operatesList: [
        { id: "1", name: "共享" },
        { id: "2", name: "群发邮件" },
        { id: "3", name: "群发短信" },
        { id: "4", name: "批量编辑" },
        { id: "5", name: "导出" },
        { id: "6", name: "下载全部附件" },
        { id: "7", name: "合并" },
        { id: "8", name: "自动查重合并" },
        { id: "9", name: "树结构设置" },
        { id: "11", name: "审批设置" },
        { id: "12", name: "恢复预设列宽" }
      ],
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      }
    }
  },
  created() {
    this.setTable()
    this.getData()
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation: [],
        tableColumn: [
          { label: "联系人姓名", prop: "name", min: 100 }, // 联系人姓名
          { label: "客户名称", prop: "client_name", min: 190 }, // 客户名称
          { label: "联系人编号", prop: "number", min: 100 }, // 联系人编号
          { label: "职务", prop: "position", min: 120 }, // 职务
          { label: "手机", prop: "phone", min: 100 }, // 手机号码
          { label: "销售负责人", prop: "member_id", min: 120 }, // 销售负责人
          { label: "首要联系人", prop: "is_first", min: 90 } // 首要联系人
        ]
      }
      this.searchOptions = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        const label = this.tableList.tableColumn[i].label
        this.searchOptions.push({ value: (i + 1).toString(), label: label })
      }
    },
    // 请求数据
    async getData() {
      this.loading = true
      await getContactList()
        .then((res) => {
          console.log(res)
          if (res.code === 200) {
            if (res.data.list && res.data.list.length > 0) {
              const list = res.data.list.map((item) => {
                return {
                  ...item,
                  client_name: item.Client.name,
                  is_first: item.is_first ? "是" : "否"
                }
              })
              this.tableList.tableInfomation = list || []
            } else {
              this.tableList.tableInfomation = []
            }
          } else {
            this.tableList.tableInfomation = []
          }
          this.loading = false
        })
        .catch((err) => {
          console.log(err)
          this.tableList.tableInfomation = []
          this.loading = false
        })
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
      this.editConfig.infomation = {
        name: "",
        number: "",
        client_id: "",
        phone: "",
        position: "",
        member_id: "",
        is_first: false,
        wechat: "",
        birthday: "",
        email: "",
        nextFollowupDate: "",
        country_id: "",
        province_id: "",
        city_id: "",
        region_id: "",
        postalCode: "",
        desc: ""
      }
    },
    // 编辑
    handleClick(row) {
      console.log(row)
      this.editConfig.visible = true
      this.editConfig.title = "编辑"
      this.editConfig.infomation = {
        id: row.id,
        birthday: row.birthday,
        city_id: row.city_id,
        client_id: 0,
        country_id: row.country_id,
        desc: row.desc,
        email: row.email,
        is_first: row.is_first || false,
        member_id: row.member_id,
        name: row.name,
        number: row.number,
        phone: row.phone,
        position: row.position,
        province_id: row.province_id,
        region_id: row.region_id,
        wechat: row.wechat
      }
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.contacts-view {
  .btn-pager {
    display: flex;
    .page {
      margin-left: auto;
    }
  }
}
</style>
